@@ -13,10 +13,9 @@ use Tk::BrowseEntry;
 use Tk::Listbox;
 use Tk::Text;
 use HTML::TokeParser;
-use Data::Dumper;
 use URI::Escape;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 Construct Tk::Widget 'HyperText';
 
@@ -2041,6 +2040,9 @@ L<Tk::ROText> and L<Tk::Text>.
 
 =head1 CHANGES
 
+  0.12 Feb 25, 2016
+  - Add more dependencies to get CPANTS to pass.
+
   0.11 Feb 23, 2016
   - Add dependency on HTML::TokeParser.
 
